@@ -3,12 +3,12 @@ package certificate
 import (
 	"context"
 
-	"github.com/hetznercloud/cli/internal/cmd/base"
-	"github.com/hetznercloud/cli/internal/hcapi2"
+	"github.com/spf13/cobra"
 	"github.com/spf13/pflag"
 
-	"github.com/hetznercloud/hcloud-go/hcloud"
-	"github.com/spf13/cobra"
+	"github.com/hetznercloud/cli/internal/cmd/base"
+	"github.com/hetznercloud/cli/internal/hcapi2"
+	"github.com/hetznercloud/hcloud-go/v2/hcloud"
 )
 
 var updateCmd = base.UpdateCmd{
