@@ -3,21 +3,22 @@ package datacenter
 import (
 	"context"
 
-	"github.com/spf13/cobra"
+	"github.com/spf13/pflag"
 
 	"github.com/hetznercloud/cli/internal/cmd/base"
 	"github.com/hetznercloud/cli/internal/cmd/output"
 	"github.com/hetznercloud/cli/internal/cmd/util"
 	"github.com/hetznercloud/cli/internal/hcapi2"
-	"github.com/hetznercloud/hcloud-go/hcloud"
-	"github.com/hetznercloud/hcloud-go/hcloud/schema"
+	"github.com/hetznercloud/hcloud-go/v2/hcloud"
+	"github.com/hetznercloud/hcloud-go/v2/hcloud/schema"
 )
 
-var listCmd = base.ListCmd{
-	ResourceNamePlural: "datacenters",
+var ListCmd = base.ListCmd{
+	ResourceNamePlural: "Datacenters",
+	JSONKeyGetByName:   "datacenters",
 	DefaultColumns:     []string{"id", "name", "description", "location"},
 
-	Fetch: func(ctx context.Context, client hcapi2.Client, cmd *cobra.Command, listOpts hcloud.ListOpts, sorts []string) ([]interface{}, error) {
+	Fetch: func(ctx context.Context, client hcapi2.Client, _ *pflag.FlagSet, listOpts hcloud.ListOpts, sorts []string) ([]interface{}, error) {
 		opts := hcloud.DatacenterListOpts{ListOpts: listOpts}
 		if len(sorts) > 0 {
 			opts.Sort = sorts
@@ -40,7 +41,7 @@ var listCmd = base.ListCmd{
 	},
 
 	JSONSchema: func(resources []interface{}) interface{} {
-		var dcSchemas []schema.Datacenter
+		dcSchemas := make([]schema.Datacenter, 0, len(resources))
 		for _, resource := range resources {
 			dc := resource.(*hcloud.Datacenter)
 			dcSchemas = append(dcSchemas, util.DatacenterToSchema(*dc))
