@@ -1,9 +1,10 @@
 package firewall
 
 import (
+	"github.com/spf13/cobra"
+
 	"github.com/hetznercloud/cli/internal/hcapi2"
 	"github.com/hetznercloud/cli/internal/state"
-	"github.com/spf13/cobra"
 )
 
 func NewCommand(cli *state.State, client hcapi2.Client) *cobra.Command {
@@ -15,16 +16,16 @@ func NewCommand(cli *state.State, client hcapi2.Client) *cobra.Command {
 		DisableFlagsInUseLine: true,
 	}
 	cmd.AddCommand(
-		listCmd.CobraCommand(cli.Context, client, cli),
+		ListCmd.CobraCommand(cli.Context, client, cli),
 		describeCmd.CobraCommand(cli.Context, client, cli),
 		newCreateCommand(cli),
 		updateCmd.CobraCommand(cli.Context, client, cli),
-		newReplaceRulesCommand(cli),
-		deleteCmd.CobraCommand(cli.Context, client, cli),
-		newAddRuleCommand(cli),
-		newDeleteRuleCommand(cli),
-		newApplyToResourceCommand(cli),
-		newRemoveFromResourceCommand(cli),
+		ReplaceRulesCommand.CobraCommand(cli.Context, client, cli, cli),
+		deleteCmd.CobraCommand(cli.Context, client, cli, cli),
+		AddRuleCommand.CobraCommand(cli.Context, client, cli, cli),
+		DeleteRuleCommand.CobraCommand(cli.Context, client, cli, cli),
+		ApplyToResourceCommand.CobraCommand(cli.Context, client, cli, cli),
+		RemoveFromResourceCommand.CobraCommand(cli.Context, client, cli, cli),
 		labelCmds.AddCobraCommand(cli.Context, client, cli),
 		labelCmds.RemoveCobraCommand(cli.Context, client, cli),
 	)
