@@ -1,9 +1,10 @@
 package floatingip
 
 import (
+	"github.com/spf13/cobra"
+
 	"github.com/hetznercloud/cli/internal/hcapi2"
 	"github.com/hetznercloud/cli/internal/state"
-	"github.com/spf13/cobra"
 )
 
 func NewCommand(cli *state.State, client hcapi2.Client) *cobra.Command {
@@ -16,14 +17,14 @@ func NewCommand(cli *state.State, client hcapi2.Client) *cobra.Command {
 	}
 	cmd.AddCommand(
 		updateCmd.CobraCommand(cli.Context, client, cli),
-		listCmd.CobraCommand(cli.Context, client, cli),
-		newCreateCommand(cli),
+		ListCmd.CobraCommand(cli.Context, client, cli),
+		CreateCommand.CobraCommand(cli.Context, client, cli, cli),
 		describeCmd.CobraCommand(cli.Context, client, cli),
-		newAssignCommand(cli),
-		newUnassignCommand(cli),
-		deleteCmd.CobraCommand(cli.Context, client, cli),
-		newEnableProtectionCommand(cli),
-		newDisableProtectionCommand(cli),
+		AssignCommand.CobraCommand(cli.Context, client, cli, cli),
+		UnassignCommand.CobraCommand(cli.Context, client, cli, cli),
+		deleteCmd.CobraCommand(cli.Context, client, cli, cli),
+		EnableProtectionCommand.CobraCommand(cli.Context, client, cli, cli),
+		DisableProtectionCommand.CobraCommand(cli.Context, client, cli, cli),
 		labelCmds.AddCobraCommand(cli.Context, client, cli),
 		labelCmds.RemoveCobraCommand(cli.Context, client, cli),
 		setRDNSCmd.CobraCommand(cli.Context, client, cli, cli),
