@@ -4,11 +4,12 @@ import (
 	"context"
 	"fmt"
 
-	"github.com/hetznercloud/cli/internal/cmd/base"
-	"github.com/hetznercloud/cli/internal/hcapi2"
 	"github.com/spf13/cobra"
 
-	"github.com/hetznercloud/hcloud-go/hcloud"
+	"github.com/hetznercloud/cli/internal/cmd/base"
+	"github.com/hetznercloud/cli/internal/cmd/util"
+	"github.com/hetznercloud/cli/internal/hcapi2"
+	"github.com/hetznercloud/hcloud-go/v2/hcloud"
 )
 
 // DescribeCmd defines a command for describing a iso.
@@ -28,6 +29,14 @@ var DescribeCmd = base.DescribeCmd{
 		fmt.Printf("Name:\t\t%s\n", iso.Name)
 		fmt.Printf("Description:\t%s\n", iso.Description)
 		fmt.Printf("Type:\t\t%s\n", iso.Type)
+		fmt.Printf(util.DescribeDeprecation(iso))
+
+		architecture := "-"
+		if iso.Architecture != nil {
+			architecture = string(*iso.Architecture)
+		}
+		fmt.Printf("Architecture:\t%s\n", architecture)
+
 		return nil
 	},
 }
