@@ -3,11 +3,12 @@ package network
 import (
 	"context"
 
+	"github.com/spf13/cobra"
+
 	"github.com/hetznercloud/cli/internal/cmd/base"
 	"github.com/hetznercloud/cli/internal/hcapi2"
-	"github.com/hetznercloud/hcloud-go/hcloud"
-
-	"github.com/spf13/cobra"
+	"github.com/hetznercloud/cli/internal/state"
+	"github.com/hetznercloud/hcloud-go/v2/hcloud"
 )
 
 var deleteCmd = base.DeleteCmd{
@@ -17,7 +18,7 @@ var deleteCmd = base.DeleteCmd{
 	Fetch: func(ctx context.Context, client hcapi2.Client, cmd *cobra.Command, idOrName string) (interface{}, *hcloud.Response, error) {
 		return client.Network().Get(ctx, idOrName)
 	},
-	Delete: func(ctx context.Context, client hcapi2.Client, cmd *cobra.Command, resource interface{}) error {
+	Delete: func(ctx context.Context, client hcapi2.Client, _ state.ActionWaiter, cmd *cobra.Command, resource interface{}) error {
 		network := resource.(*hcloud.Network)
 		if _, err := client.Network().Delete(ctx, network); err != nil {
 			return err
