@@ -4,12 +4,14 @@ import (
 	"context"
 	"net"
 	"testing"
+	"time"
 
 	"github.com/golang/mock/gomock"
+	"github.com/stretchr/testify/assert"
+
 	"github.com/hetznercloud/cli/internal/cmd/network"
 	"github.com/hetznercloud/cli/internal/testutil"
-	"github.com/hetznercloud/hcloud-go/hcloud"
-	"github.com/stretchr/testify/assert"
+	"github.com/hetznercloud/hcloud-go/v2/hcloud"
 )
 
 func TestList(t *testing.T) {
@@ -36,14 +38,15 @@ func TestList(t *testing.T) {
 				Name:    "test-net",
 				IPRange: &net.IPNet{IP: net.ParseIP("192.0.2.1"), Mask: net.CIDRMask(24, 32)},
 				Servers: []*hcloud.Server{{ID: 3421}},
+				Created: time.Now().Add(-10 * time.Second),
 			},
 		},
 			nil)
 
 	out, err := fx.Run(cmd, []string{"--selector", "foo=bar"})
 
-	expOut := `ID    NAME       IP RANGE       SERVERS
-123   test-net   192.0.2.1/24   1 server
+	expOut := `ID    NAME       IP RANGE       SERVERS    AGE
+123   test-net   192.0.2.1/24   1 server   10s
 `
 
 	assert.NoError(t, err)
