@@ -1,9 +1,10 @@
 package network
 
 import (
+	"github.com/spf13/cobra"
+
 	"github.com/hetznercloud/cli/internal/hcapi2"
 	"github.com/hetznercloud/cli/internal/state"
-	"github.com/spf13/cobra"
 )
 
 func NewCommand(cli *state.State, client hcapi2.Client) *cobra.Command {
@@ -19,16 +20,17 @@ func NewCommand(cli *state.State, client hcapi2.Client) *cobra.Command {
 		DescribeCmd.CobraCommand(cli.Context, client, cli),
 		newCreateCommand(cli),
 		updateCmd.CobraCommand(cli.Context, client, cli),
-		deleteCmd.CobraCommand(cli.Context, client, cli),
-		newChangeIPRangeCommand(cli),
-		newAddRouteCommand(cli),
-		newRemoveRouteCommand(cli),
-		newAddSubnetCommand(cli),
-		newRemoveSubnetCommand(cli),
+		deleteCmd.CobraCommand(cli.Context, client, cli, cli),
+		ChangeIPRangeCommand.CobraCommand(cli.Context, client, cli, cli),
+		AddRouteCommand.CobraCommand(cli.Context, client, cli, cli),
+		RemoveRouteCommand.CobraCommand(cli.Context, client, cli, cli),
+		AddSubnetCommand.CobraCommand(cli.Context, client, cli, cli),
+		RemoveSubnetCommand.CobraCommand(cli.Context, client, cli, cli),
 		labelCmds.AddCobraCommand(cli.Context, client, cli),
 		labelCmds.RemoveCobraCommand(cli.Context, client, cli),
-		newEnableProtectionCommand(cli),
-		newDisableProtectionCommand(cli),
+		EnableProtectionCommand.CobraCommand(cli.Context, client, cli, cli),
+		DisableProtectionCommand.CobraCommand(cli.Context, client, cli, cli),
+		ExposeRoutesToVSwitchCommand.CobraCommand(cli.Context, client, cli, cli),
 	)
 	return cmd
 }
