@@ -3,12 +3,14 @@ package placementgroup_test
 import (
 	"context"
 	"testing"
+	"time"
 
 	"github.com/golang/mock/gomock"
+	"github.com/stretchr/testify/assert"
+
 	"github.com/hetznercloud/cli/internal/cmd/placementgroup"
 	"github.com/hetznercloud/cli/internal/testutil"
-	"github.com/hetznercloud/hcloud-go/hcloud"
-	"github.com/stretchr/testify/assert"
+	"github.com/hetznercloud/hcloud-go/v2/hcloud"
 )
 
 func TestList(t *testing.T) {
@@ -37,15 +39,16 @@ func TestList(t *testing.T) {
 				ID:      897,
 				Name:    "my Placement Group",
 				Labels:  map[string]string{"key": "value"},
-				Servers: []int{4711, 4712},
+				Servers: []int64{4711, 4712},
 				Type:    hcloud.PlacementGroupTypeSpread,
+				Created: time.Now().Add(-10 * time.Second),
 			},
 		}, nil)
 
 	out, err := fx.Run(cmd, []string{"--selector", "foo=bar"})
 
-	expOut := `ID    NAME                 SERVERS     TYPE
-897   my Placement Group   2 servers   spread
+	expOut := `ID    NAME                 SERVERS     TYPE     AGE
+897   my Placement Group   2 servers   spread   10s
 `
 
 	assert.NoError(t, err)
