@@ -1,9 +1,10 @@
 package placementgroup
 
 import (
+	"github.com/spf13/cobra"
+
 	"github.com/hetznercloud/cli/internal/hcapi2"
 	"github.com/hetznercloud/cli/internal/state"
-	"github.com/spf13/cobra"
 )
 
 func NewCommand(cli *state.State, client hcapi2.Client) *cobra.Command {
@@ -19,7 +20,7 @@ func NewCommand(cli *state.State, client hcapi2.Client) *cobra.Command {
 		ListCmd.CobraCommand(cli.Context, client, cli),
 		DescribeCmd.CobraCommand(cli.Context, client, cli),
 		UpdateCmd.CobraCommand(cli.Context, client, cli),
-		DeleteCmd.CobraCommand(cli.Context, client, cli),
+		DeleteCmd.CobraCommand(cli.Context, client, cli, cli),
 		LabelCmds.AddCobraCommand(cli.Context, client, cli),
 		LabelCmds.RemoveCobraCommand(cli.Context, client, cli),
 	)
