@@ -4,23 +4,23 @@ import (
 	"context"
 	"fmt"
 
-	"github.com/hetznercloud/cli/internal/cmd/cmpl"
+	"github.com/spf13/cobra"
 
 	"github.com/hetznercloud/cli/internal/cmd/base"
+	"github.com/hetznercloud/cli/internal/cmd/cmpl"
 	"github.com/hetznercloud/cli/internal/hcapi2"
 	"github.com/hetznercloud/cli/internal/state"
-	"github.com/hetznercloud/hcloud-go/hcloud"
-	"github.com/spf13/cobra"
 )
 
 var DisableProtectionCmd = base.Cmd{
 	BaseCobraCommand: func(client hcapi2.Client) *cobra.Command {
 		cmd := &cobra.Command{
-			Use:   "disable-protection PRIMARYIP",
+			Use:   "disable-protection PRIMARYIP [PROTECTIONLEVEL...]",
 			Short: "Disable Protection for a Primary IP",
-			Args:  cobra.ExactArgs(1),
+			Args:  cobra.MinimumNArgs(1),
 			ValidArgsFunction: cmpl.SuggestArgs(
 				cmpl.SuggestCandidatesF(client.PrimaryIP().Names),
+				cmpl.SuggestCandidates("delete"),
 			),
 			TraverseChildren:      true,
 			DisableFlagsInUseLine: true,
@@ -37,21 +37,17 @@ var DisableProtectionCmd = base.Cmd{
 			return fmt.Errorf("Primary IP not found: %v", idOrName)
 		}
 
-		opts := hcloud.PrimaryIPChangeProtectionOpts{
-			ID:     primaryIP.ID,
-			Delete: false,
+		// This command used to have the "delete" protection level as the default.
+		// To avoid a breaking change, we now add it if no level is defined.
+		if len(args) < 2 {
+			args = append(args, "delete")
 		}
 
-		action, _, err := client.PrimaryIP().ChangeProtection(ctx, opts)
+		opts, err := getChangeProtectionOpts(false, args[1:])
 		if err != nil {
 			return err
 		}
 
-		if err := actionWaiter.ActionProgress(ctx, action); err != nil {
-			return err
-		}
-
-		fmt.Printf("Primary IP %d protection disabled", opts.ID)
-		return nil
+		return changeProtection(ctx, client, actionWaiter, primaryIP, false, opts)
 	},
 }
