@@ -5,9 +5,10 @@ import (
 	"testing"
 
 	"github.com/golang/mock/gomock"
-	"github.com/hetznercloud/cli/internal/testutil"
-	"github.com/hetznercloud/hcloud-go/hcloud"
 	"github.com/stretchr/testify/assert"
+
+	"github.com/hetznercloud/cli/internal/testutil"
+	"github.com/hetznercloud/hcloud-go/v2/hcloud"
 )
 
 func TestEnableProtection(t *testing.T) {
@@ -45,7 +46,7 @@ func TestEnableProtection(t *testing.T) {
 	fx.ActionWaiter.EXPECT().ActionProgress(gomock.Any(), action).Return(nil)
 	out, err := fx.Run(cmd, []string{"13"})
 
-	expOut := "Primary IP 13 protection enabled"
+	expOut := "Resource protection enabled for primary IP 13\n"
 
 	assert.NoError(t, err)
 	assert.Equal(t, expOut, out)
