@@ -4,22 +4,24 @@ import (
 	"context"
 	"net"
 	"testing"
+	"time"
 
 	"github.com/golang/mock/gomock"
-	"github.com/hetznercloud/cli/internal/testutil"
-	"github.com/hetznercloud/hcloud-go/hcloud"
 	"github.com/stretchr/testify/assert"
+
+	"github.com/hetznercloud/cli/internal/testutil"
+	"github.com/hetznercloud/hcloud-go/v2/hcloud"
 )
 
 func TestList(t *testing.T) {
 	fx := testutil.NewFixture(t)
 	defer fx.Finish()
 
-	cmd := listCmd.CobraCommand(context.Background(), fx.Client, fx.TokenEnsurer)
+	cmd := ListCmd.CobraCommand(context.Background(), fx.Client, fx.TokenEnsurer)
 
 	fx.ExpectEnsureToken()
 	fx.Client.PrimaryIPClient.EXPECT().
-		List(
+		AllWithOpts(
 			gomock.Any(),
 			hcloud.PrimaryIPListOpts{
 				ListOpts: hcloud.ListOpts{
@@ -36,15 +38,15 @@ func TestList(t *testing.T) {
 				AutoDelete: true,
 				Type:       hcloud.PrimaryIPTypeIPv4,
 				IP:         net.ParseIP("127.0.0.1"),
+				Created:    time.Now().Add(-10 * time.Second),
 			},
 		},
-			&hcloud.Response{},
 			nil)
 
 	out, err := fx.Run(cmd, []string{"--selector", "foo=bar"})
 
-	expOut := `ID    TYPE   NAME       IP          ASSIGNEE   DNS   AUTO DELETE
-123   ipv4   test-net   127.0.0.1   -          -     yes
+	expOut := `ID    TYPE   NAME       IP          ASSIGNEE   DNS   AUTO DELETE   AGE
+123   ipv4   test-net   127.0.0.1   -          -     yes           10s
 `
 
 	assert.NoError(t, err)
