@@ -5,9 +5,10 @@ import (
 	"testing"
 
 	"github.com/golang/mock/gomock"
-	"github.com/hetznercloud/cli/internal/testutil"
-	"github.com/hetznercloud/hcloud-go/hcloud"
 	"github.com/stretchr/testify/assert"
+
+	"github.com/hetznercloud/cli/internal/testutil"
+	"github.com/hetznercloud/hcloud-go/v2/hcloud"
 )
 
 func TestUnAssign(t *testing.T) {
@@ -30,7 +31,7 @@ func TestUnAssign(t *testing.T) {
 	fx.Client.PrimaryIPClient.EXPECT().
 		Unassign(
 			gomock.Any(),
-			13,
+			int64(13),
 		).
 		Return(
 			action,
