@@ -4,11 +4,11 @@ import (
 	"context"
 	"net"
 
+	"github.com/spf13/cobra"
+
 	"github.com/hetznercloud/cli/internal/cmd/base"
 	"github.com/hetznercloud/cli/internal/hcapi2"
-
-	"github.com/hetznercloud/hcloud-go/hcloud"
-	"github.com/spf13/cobra"
+	"github.com/hetznercloud/hcloud-go/v2/hcloud"
 )
 
 var setRDNSCmd = base.SetRdnsCmd{
