@@ -5,14 +5,13 @@ import (
 	"fmt"
 	"strings"
 
-	"github.com/hetznercloud/cli/internal/cmd/base"
-	"github.com/hetznercloud/cli/internal/hcapi2"
+	"github.com/dustin/go-humanize"
 	"github.com/spf13/cobra"
 
-	"github.com/dustin/go-humanize"
-
+	"github.com/hetznercloud/cli/internal/cmd/base"
 	"github.com/hetznercloud/cli/internal/cmd/util"
-	"github.com/hetznercloud/hcloud-go/hcloud"
+	"github.com/hetznercloud/cli/internal/hcapi2"
+	"github.com/hetznercloud/hcloud-go/v2/hcloud"
 )
 
 var describeCmd = base.DescribeCmd{
