@@ -34,7 +34,7 @@ func (c *firewallClient) Names() []string {
 	for i, firewall := range firewalls {
 		name := firewall.Name
 		if name == "" {
-			name = strconv.Itoa(firewall.ID)
+			name = strconv.FormatInt(firewall.ID, 10)
 		}
 		names[i] = name
 	}
