@@ -10,6 +10,7 @@ import (
 type LocationClient interface {
 	LocationClientBase
 	Names() []string
+	NetworkZones() []string
 }
 
 func NewLocationClient(client LocationClientBase) LocationClient {
@@ -33,9 +34,31 @@ func (c *locationClient) Names() []string {
 	for i, loc := range locs {
 		name := loc.Name
 		if name == "" {
-			name = strconv.Itoa(loc.ID)
+			name = strconv.FormatInt(loc.ID, 10)
 		}
 		names[i] = name
 	}
 	return names
 }
+
+// NetworkZones obtains a list of available network zones. It returns nil if
+// location data could not be fetched.
+func (c *locationClient) NetworkZones() []string {
+	locs, err := c.All(context.Background())
+	if err != nil || len(locs) == 0 {
+		return nil
+	}
+
+	zones := make(map[string]bool)
+	for _, loc := range locs {
+		if loc.NetworkZone != "" {
+			zones[string(loc.NetworkZone)] = true
+		}
+	}
+
+	var zoneList []string
+	for zone := range zones {
+		zoneList = append(zoneList, zone)
+	}
+	return zoneList
+}
